// ----------------------------------------------------------------------------
//
// PneuGreifMain.PAS                                     Ulrich Mller 27.12.99
//                                                       Procida 400NT  Delphi4
// Pneumatischer Greifer : Delphi4 Adaption
//                        des LLWin Programms PneuSort.MDL der Pneumatic Robots
// Zyklus : GreifArm geht nach Position A, holt das Teil und setzt es auf
// Pos. B ab, Leerrunde, Teil zurck nach A, Leerrunde.
//
// Der jeweilige Status wird auf der Form angezeigt (lblStatus)
//
// Nutzung umFish.DLL, ggf. PortNamen anpassen
// Armxx und Greiferxx :
// Die Waitfunktionen wurden in die Funktionen integriert.
// Ebenfalls die Resetfunktion, sie knnte auch zentrale in WaitForTime
// eingebaut werden (wenn der Eingang immer dafr zur Verfgung steht).
// Die Statusanzeige wurde vor WaitForTime plaziert, um eine Anzeige zu
// gewhrleisten (danach wird nichts).
//
// ----------------------------------------------------------------------------

unit PneuGreifMain;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  TfrmGreifMain = class(TForm)
    cmdStart: TButton;
    cmdHalt: TButton;
    cmdEnde: TButton;
    lblTitel: TLabel;
    lblCopyright: TLabel;
    lblStatus: TLabel;
    procedure cmdEndeClick(Sender: TObject);
    procedure cmdHaltClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure cmdStartClick(Sender: TObject);
  private
    procedure ArmPosA();
    procedure ArmPosB();
    procedure GreiferAuf();
    procedure GreiferZu();
    procedure GreifMain();
  public
    { Public-Deklarationen}
  end;

  var
     frmGreifMain: TfrmGreifMain;

implementation

{$R *.DFM}

uses umFish;

const
     cvArmA = 1; cvArmB = 2; cvGreifer = 3;   // --- Magnetventile
     cmKompressor = 4;                        // --- Motor
     ctReset = 8;                             // --- Taster
var
  FishFace: TftiDCB; pFishFace: TpftiDCB;

procedure TfrmGreifMain.cmdEndeClick(Sender: TObject);
begin
     close;
end;

procedure TfrmGreifMain.cmdHaltClick(Sender: TObject);
// --- Setzen NotHalt, um Ende einzuleiten ----------
begin
     cmdStart.SetFocus;
     NotHalt := true;
end;

procedure TfrmGreifMain.FormCreate(Sender: TObject);
begin
     pFishFace := @FishFace;
     NotHalt := true;
end;

procedure TfrmGreifMain.cmdStartClick(Sender: TObject);
// --------- Starten der SortSteuerung ----------------
begin
     cmdHalt.SetFocus;
     if NotHalt then              // --- Ist beim Programmstart true
     begin
          NotHalt := false;
          if OpenInterface(pFishFace, 'COM1') = ftiFehler then
          begin
            MessageDlg('InterfaceProblem', mtInformation,[mbOK], 0);
            exit;
          end;                                    { ggf COMx anpassen }
          GreifMain;               // --- umSichGreifen
          ClearMotors(pFishFace);  // --- Ende
          cmdStart.SetFocus;
          lblStatus.Caption := 'START/ENDE';
          CloseInterface(pFishFace);
     end;
end;


procedure TfrmGreifMain.ArmPosA;
// --- Arm nach Position A -----
begin
  SetMotor(pFishFace, cvArmB, ftiAus);
  SetMotor(pFishFace, cvArmA, ftiEin);
  if GetInput(pFishFace, ctReset) then exit;   // --- Abbruch durch Reset
  lblStatus.Caption := 'Position A';
  WaitForTime(pFishFace, 2000);
end;

procedure TfrmGreifMain.ArmPosB;
// --- Arm nach Position B -----
begin
  SetMotor(pFishFace, cvArmA, ftiAus);
  SetMotor(pFishFace, cvArmB, ftiEin);
  if GetInput(pFishFace, ctReset) then exit;   // --- Abbruch durch Reset
  lblStatus.Caption := 'Position B';
  WaitForTime(pFishFace, 2000);
end;

procedure TfrmGreifMain.GreiferAuf;
// --- Greifer ffnen -------------
begin
  SetMotor(pFishFace, cvGreifer, ftiAus);
  if GetInput(pFishFace, ctReset) then exit;   // --- Abbruch durch Reset
  lblStatus.Caption := 'Greifer Auf';
  WaitForTime(pFishFace, 2000);
end;

procedure TfrmGreifMain.GreiferZu;
// ---- Greifer schlieen --------
begin
  SetMotor(pFishFace, cvGreifer, ftiEin);
  if GetInput(pFishFace, ctReset) then exit;   // --- Abbruch durch Reset
  lblStatus.Caption := 'Greifer Zu';
  WaitForTime(pFishFace, 2000);
end;

procedure TfrmGreifMain.GreifMain;
// --- Hauptprogramm, Schleife, die ber NotHalt bzw. Reset beendet wird ---
begin
  SetMotor(pFishFace, cmKompressor, ftiEin);    // --- Startphase
  WaitForTime(pFishFace, 6000);
  GreiferAuf;
  ArmPosA;
  lblStatus.Caption := 'Anlage ready';

  repeat
    GreiferZu;
    ArmPosB;
    GreiferAuf;
    ArmPosA;
    ArmPosB;
    GreiferZu;
    ArmPosA;
    GreiferAuf;
    ArmPosB;
    ArmPosA;
  until NotHalt OR GetInput(pFishFace, ctReset);
end;

end.
